@@ -1,13 +1,12 @@
 import sys
 import time
-import json
-from docopt import docopt
+import jason_gnss.exif as exif
 
 from roktools import logger
 
-from . import InvalidResponse, jason
+from . import jason
 
-def process(rover_file, process_type="GNSS", base_file=None, base_lonlathgt=None, timeout=None, **kwargs):
+def process(rover_file, process_type="GNSS", base_file=None, base_lonlathgt=None, images_folder=None, timeout=None, **kwargs):
     """
     Submit a process to Jason and wait for it to end so that the results file
     is also download
@@ -17,7 +16,7 @@ def process(rover_file, process_type="GNSS", base_file=None, base_lonlathgt=None
     logger.debug('Timeout  {}'.format(timeout))
 
     process_id = submit(rover_file, process_type=process_type, 
-                 base_file=base_file, base_lonlathgt=base_lonlathgt, **kwargs)
+                 base_file=base_file, base_lonlathgt=base_lonlathgt, images_folder=images_folder, **kwargs)
 
     if process_id is None:
         logger.critical('Could not submit [ {} ] for processing'.format(rover_file))
@@ -51,8 +50,6 @@ def process(rover_file, process_type="GNSS", base_file=None, base_lonlathgt=None
                             "but might be available for download at a later stage.")
             return None
 
-    logger.critical('Unexpected error occured')
-    return None
 
 # ------------------------------------------------------------------------------
 
@@ -73,25 +70,31 @@ def status(process_id, **kwargs):
 
 # ------------------------------------------------------------------------------
 
-def submit(rover_file, process_type="GNSS", base_file=None, base_lonlathgt=None, **kwargs):
+def submit(rover_file, process_type="GNSS", base_file=None, base_lonlathgt=None, images_folder=None, **kwargs):
     """
     Submit a process to the server without waiting for it to end
     """
 
     res = None
+    camera_metadata_file = None
+
+    if images_folder:
+        camera_metadata_file = exif.get_exif_tags_file(images_folder=images_folder)
+        if camera_metadata_file is None:
+            logger.critical('It was not possible to generate the camera metadata file.')
+
+    ret, return_code = jason.submit_process(rover_file,
+                        process_type=process_type, base_file=base_file,
+                        base_lonlathgt=base_lonlathgt, camera_metadata_file=camera_metadata_file, **kwargs)
 
-    ret, return_code = jason.submit_process(rover_file, 
-                        process_type=process_type, 
-                        base_file=base_file, base_lonlathgt=base_lonlathgt, **kwargs)
-    
     if return_code == 200:
         res =  ret['id']
-
+        
     return res
 
 # ------------------------------------------------------------------------------
 
-def download(process_id, **kwargs):
+def download(process_id, **_):
     """
     Download the results for the given process_id
     """
@@ -104,12 +107,12 @@ def download(process_id, **kwargs):
 
 # ------------------------------------------------------------------------------
 
-def list_processes(**kwargs):
+def list_processes(user_only=True, **_):
     """
     List the processes issued by the user
     """
 
-    processes = jason.list_processes()
+    processes = jason.list_processes(user_only=user_only)
 
     res = None
 
@@ -125,10 +128,17 @@ def list_processes(**kwargs):
 
         if res is None:
             res = ""
-        res += ','.join([str(process[k]) for k in process])
+        res += ','.join([str(process[k]) for k in process]) + '\n'
 
     return res
 
+# ------------------------------------------------------------------------------
+
+def api_status():
+
+    return jason.api_status()
+
+# ------------------------------------------------------------------------------
 
 def __spinning_cursor__(flavour='basic'):
 
