@@ -1,7 +1,6 @@
 import requests
 import os
 import os.path
-import urllib
 import tempfile
 
 from roktools import logger
@@ -33,11 +32,12 @@ def status(platform, app_version, api_key=None, secret_token=None):
 
     return r.json(), r.status_code
 
+# ------------------------------------------------------------------------------
 
 def submit_process(rover_file, process_type="GNSS", 
-                    base_file=None, base_lonlathgt=None,
+                    base_file=None, base_lonlathgt=None, camera_metadata_file=None,
                     api_key=None, secret_token=None, rover_dynamics='dynamic',
-                    strategy=None, label="jason-gnss"):
+                    strategy='PPK/PPP', label="jason-gnss"):
     """
     Submit a process to Jason PaaS
 
@@ -45,6 +45,7 @@ def submit_process(rover_file, process_type="GNSS",
     :param process_type: Type of process to submit to Jason (GNSS or CONVERSION)
     :param base_file: Filename with the GNSS measurements of the base receiver
     :param base_lonlathgt: Array with the longitude, latitude and height
+    :param camera_metadata_file: Filename with the exif data of the images in the folder
     :param api_key: Jason API key, if not provided will be fetched from the 
                     environement variables
     :param secret_token: Your Jason user secret token, if not provided will be 
@@ -66,6 +67,7 @@ def submit_process(rover_file, process_type="GNSS",
 
     rover_file_fh = open(rover_file, 'rb')
     base_file_fh = open(base_file, 'rb') if base_file else None
+    camera_metadata_file_fh = open(camera_metadata_file, 'rb') if camera_metadata_file else None
 
     api_key, secret_token = __fetch_credentials__(api_key, secret_token)
 
@@ -80,7 +82,8 @@ def submit_process(rover_file, process_type="GNSS",
         'token' : (None, secret_token),
         'rover_file': (rover_file, rover_file_fh),
         'rover_dynamics': (None, rover_dynamics),
-        'label': (None, label)
+        'label': (None, label),
+        'camera_metadata_file': (camera_metadata_file, camera_metadata_file_fh)
     }
 
     if base_file:
@@ -90,6 +93,9 @@ def submit_process(rover_file, process_type="GNSS",
     if config_file:
         files.update({'config_file' : ('config_file', config_file_fh)})
 
+    if camera_metadata_file:
+        files.update({'camera_metadata_file' : (camera_metadata_file, camera_metadata_file_fh)})
+
     if base_lonlathgt:
         lon = base_lonlathgt[0]
         lat = base_lonlathgt[1]
@@ -110,9 +116,13 @@ def submit_process(rover_file, process_type="GNSS",
     if config_file_fh:
         config_file_fh.close()
         os.remove(config_file)
+    if camera_metadata_file_fh:
+        camera_metadata_file_fh.close()
 
     return r.json(), r.status_code
 
+# ------------------------------------------------------------------------------
+
 def get_status(process_id, api_key=None, secret_token=None):
     """
     Check the status of a specific process_id
@@ -131,6 +141,7 @@ def get_status(process_id, api_key=None, secret_token=None):
 
     return r.json(), r.status_code
 
+# ------------------------------------------------------------------------------
 
 def download_results(process_id, api_key=None, secret_token=None):
     """
@@ -159,36 +170,93 @@ def download_results(process_id, api_key=None, secret_token=None):
     
     return results_file_name
 
-def list_processes(api_key=None, secret_token=None):
+# ------------------------------------------------------------------------------
+
+def list_processes(api_key=None, secret_token=None, user_only=True):
     """
-    List the processess that the user has issued
+    List the processess issued by the user (or all processes if the user has admin
+    privileges)
     """
 
     api_key, secret_token = __fetch_credentials__(api_key, secret_token)
 
+    if user_only:
+        url, headers, params, fields = __get_args_for_own_processes(api_key, secret_token)
+    else:
+        url, headers, params, fields = __get_args_for_all_processes(api_key, secret_token)
+
+    r = requests.get(url, headers=headers, params=params)
+
+    processes = []
+    if r.status_code == 200:
+        processes = [__filter_process_info__(p, fields=fields) for p in r.json()]    
+    elif r.status_code == 403:
+        logger.critical('You need admin privileges to get all processes')
+
+    return processes
+
+def __get_args_for_own_processes(api_key, secret_token):
+
     url='{}/users/{}/processes'.format(API_URL, secret_token)
 
     headers = __build_headers__(api_key)
     params = {}
 
+    fields = ['id', 'type', 'status', 'source_file', 'created']
+
+    return url, headers, params, fields
+
+def __get_args_for_all_processes(api_key, secret_token, status='FINISHED'):
+
+    url='{}/processes'.format(API_URL)
+   
+    headers = __build_headers__(api_key)
+    params = { 
+        'status' : status,
+        'token' : secret_token
+    }
+
+    fields = ['id', 'type', 'email', 'status', 'source_file', 'created', 'dynamic', 'strategy', 'num_epochs']
+ 
+    return url, headers, params, fields
+
+# ------------------------------------------------------------------------------
+
+def api_status(api_key=None):
+    """
+    Get the API status, containing the version of the software running the versions
+    """
+
+    api_key, _ = __fetch_credentials__(api_key, None)
+
+    url='{}/status'.format(API_URL)
+
+    headers = __build_headers__(api_key)
+    params = {}
+
     r = requests.get(url, headers=headers, params=params)
 
-    processes = []
     if r.status_code == 200:
-        processes = [__filter_process_info__(p) for p in r.json()]    
-
-    return processes
-
-def __filter_process_info__(process_info):
-
-    FIELDS = ['id', 'type', 'status', 'source_file', 'created']
-
-    out = { k:process_info[k] for k in FIELDS}
-
-    out['source_file'] = process_info['source_file'].split('/')[-1]
+        out = r.json()
+        out.pop('success')
+    else:
+        out = None
 
     return out
 
+# ------------------------------------------------------------------------------
+
+def __filter_process_info__(process_info, fields):
+
+    out = { k:process_info[k] for k in fields}
+
+    source_file = process_info.get('source_file', "")
+    out['source_file'] = source_file.split('/')[-1]
+
+    return out
+
+# ------------------------------------------------------------------------------
+
 
 def __build_headers__(api_key):
     """
@@ -203,6 +271,8 @@ def __build_headers__(api_key):
 
     return headers
 
+# ------------------------------------------------------------------------------
+
 def __fetch_credentials__(api_key, secret_token):
 
     if api_key is None:
@@ -216,6 +286,8 @@ def __fetch_credentials__(api_key, secret_token):
 
     return api_key, secret_token
 
+# ------------------------------------------------------------------------------
+
 def __create_config_file__(base_lonlathgt=None):
 
     fh, name = tempfile.mkstemp(prefix='config_file_', text=True)
@@ -238,6 +310,8 @@ def __create_config_file__(base_lonlathgt=None):
 
     return name, fh
 
+# ------------------------------------------------------------------------------
+
 def __check_process_id__(process_id):
 
     import re
