@@ -15,13 +15,15 @@ Usage:
     jason process   <rover_file> [ <base_file> ] [ -p <lat> <lon> <height> ] 
                                  [-l <label>] [--dynamics <dynamic_type>] 
                                  [-s <strategy>] [-t <seconds>] [-d <level>]
+                                 [-i <images_folder>]
     jason submit    <rover_file> [ <base_file> ] [ -p <lat> <lon> <height> ] 
                                  [-l <label>] [--dynamics <dynamic_type>] 
                                  [-s <strategy>] [-d <level>]
+                                 [-i <images_folder>]
     jason download  <process_id> [-d <level>]
     jason status    <process_id> [-d <level>]
     jason convert   <gnss_file> [-d <level>]
-    jason list_processes
+    jason list_processes [--all]
 
 Options:
     -h --help           shows the help
@@ -44,6 +46,12 @@ Options:
                         Optional base station position (in WGS84 format)
     -t --timeout <seconds>  Maximum time to wait until the process is finished.
                         If not specified, it will wait until process is done.
+    -i --images_folder <images_folder>
+                        Specify the path of the folder containing the images for the photogrametic data. 
+                        Obtains the metadata (EXIF) from the images in folder to match them with their
+                        corresponding events.
+    --all               List all processes instead of those for the user only
+                        (requires an admin token)
 
 Commands:
     process        Submit a file to process and wait for the results (returns the process id)
@@ -123,6 +131,9 @@ def __get_command__(args):
     
     elif args['list_processes']:
         command = commands.list_processes
+        command_args = {
+            'user_only': not args.get('--all', False),
+        }
 
     return command, command_args
 
@@ -152,6 +163,9 @@ def __get_submit_args__(args):
     if '--strategy' in args and args['--strategy'] != "auto":
         command_args.update({'strategy' : args['--strategy']})
 
+    if '--images_folder' in args:
+        command_args.update({'images_folder' : args['--images_folder']})
+
     return command_args
 
 
